@@ -3,7 +3,7 @@
 from pagador import settings
 from pagador.extensao.base import Plugavel, PluginNaoEncontrado
 from pagador.pedido import notificador
-from pagador.retorno.models import PedidoPagamento
+from pagador.retorno.models import PedidoPagamento, Pedido
 from pagador.retorno.notificador import grava_evidencia_retorno
 from pagador.seguranca.autenticador import Conexao, TipoConexao
 
@@ -74,6 +74,18 @@ class RegistrarPagamento(Plugavel):
                 self._conta_id = None
         return self._conta_id
 
+    @property
+    def achou_registro(self):
+        if not self.conta_id:
+            return False
+        if not self.registrador.pedido_numero:
+            return False
+        try:
+            Pedido.objects.get(conta_id=self.conta_id, numero=self.registrador.pedido_numero)
+            return True
+        except Exception:
+            return False
+
     def processar_resposta(self, resposta):
         if getattr(self.registrador, "processa_resposta", False):
             return self.registrador.processar_resposta(resposta)
@@ -81,17 +93,21 @@ class RegistrarPagamento(Plugavel):
 
     def processar(self):
         resultado = {}
-        if settings.GRAVA_EVIDENCIA:
-            self.dados["tipo"] = self.tipo
-            grava_evidencia_retorno(self.meio_pagamento, self.dados)
-            resultado["evidencia"] = True
         if self.registrador.obter_dados_do_gateway:
             self.registrador.dados.update(self.obtem_dados_do_gateway())
         if self.registrador.alterar_situacao:
-            if not self.conta_id:
-                return {"resultado": "erro", "mensagem": u"Não foi possível alterar o status do pedido, pois a conta não foi identificada com as informações passadas."}
-            resultado["situacao"] = u"Alterado para {}".format(self.registrador.situacao_do_pedido)
-            notificador.envia_alteracao_de_situacao_de_pedido(self.registrador.pedido_numero, self.registrador.situacao_do_pedido, self.conta_id)
+            if self.achou_registro:
+                resultado["pedido_venda_situacao"] = self.registrador.situacao_do_pedido
+                notificador.envia_alteracao_de_situacao_de_pedido(self.registrador.pedido_numero, self.registrador.situacao_do_pedido, self.conta_id)
+            else:
+                resultado = {"resultado": "erro", "mensagem": u"Nada foi registrado, pois os valores retornados não compõem um registro válido na LI."}
+        if settings.GRAVA_EVIDENCIA:
+            self.dados["tipo"] = self.tipo
+            tipo_evidencia = "pagador-retorno" if self.tipo == "retorno" else "pagador-redirect"
+            enviado = {"status_code": 200}
+            enviado.update(resultado)
+            grava_evidencia_retorno(self.meio_pagamento, self.dados, tipo_evidencia=tipo_evidencia, registrado=self.achou_registro, enviado=enviado)
+            resultado["evidencia"] = True
         if self.registrador.redireciona_para:
             return {"redirect": self.registrador.redireciona_para}
         resultado["resultado"] = "OK"
